==> thyi-1.0.10.tar.gz: lib/src/thyi.dart <==
import 'dart:async';

import 'package:cookie_jar/cookie_jar.dart';
import 'package:dio/dio.dart';
import 'package:dio_cookie_manager/dio_cookie_manager.dart';
import 'package:thyi/src/util/util_log.dart';

class Thyi {
  Dio dio;

  Interceptors get interceptors {
    return dio.interceptors;
  }

  /// param persisCookie: 是否持久化cookie，传false，会只将cookie存入内存。程序退出，消失
  Thyi(String baseUrl, {bool enableLog = true, bool persisCookie = true}) {
    isLogEnable = enableLog;
    dio = Dio(BaseOptions(baseUrl: baseUrl));
    interceptors.add(CookieManager(persisCookie? PersistCookieJar() : CookieJar()));
  }

}

/// 代表某条api
class ApiMethod {
  String method;
  String path = '';
  Map<String, String> headers = {};
  Map<String, String> fields = {};
  Map<String, String> queries = {};

  ApiMethod(this.method, this.path, {this.headers, this.fields, this.queries});

  Future<String> send(Thyi thyi) {
    var options = Options();
    var dio = thyi.dio;
    
    if (headers != null && headers.isNotEmpty) {
      options.headers.addAll(headers);
    }

    logi('url: ${dio.options.baseUrl}, path: ${path} fileds: ${fields}');
    /// How to handle all method?
    if (isGet()) {
      return dio.get<String>(path, queryParameters: queries, options: options)
        .then((response) => _parseResponse(response));
    }
    else if (isPost()) {
      return dio.post<String>(path, queryParameters: queries, options: options, data: fields)
        .then((response) => _parseResponse(response));
    }
    else if (isDelete()) {
      return dio.delete<String>(path, queryParameters: queries, options: options, data: fields)
          .then((response) => _parseResponse(response));
    }
    else {
      return Future.error('for now unsupport http method; ${method}');
    }

  }  

  String _parseResponse(Response response) {
    var rst = response.data.toString();
    logi("response: $rst");
    return rst;
  }


  bool isGet() {
    return "GET" == method.toUpperCase();
  }

  bool isPost() {
    return "POST" == method.toUpperCase();
  }

  bool isDelete() {
    return "DELETE" == method.toUpperCase();
  }
}

==> thyi-1.0.11.tar.gz: lib/src/thyi.dart <==
import 'dart:async';
import 'dart:io';

import 'package:cookie_jar/cookie_jar.dart';
import 'package:dio/dio.dart';
import 'package:dio_cookie_manager/dio_cookie_manager.dart';
import 'package:path_provider/path_provider.dart';
import 'package:thyi/src/util/util_log.dart';

class Thyi {
  static String _cookiePath = "";

  static void init() async {
    Directory tempDir = await getTemporaryDirectory();
    _cookiePath = tempDir.path;
  }

  Dio dio;

  Interceptors get interceptors {
    return dio.interceptors;
  }

  /// param persisCookie: 是否持久化cookie，传false，会只将cookie存入内存。程序退出，消失
  Thyi(String baseUrl, {bool enableLog = true, bool persisCookie = true}) {
    isLogEnable = enableLog;
    dio = Dio(BaseOptions(baseUrl: baseUrl));
    CookieJar cookieJar;
    if (persisCookie) {
      if (_cookiePath.isEmpty) {
        throw "You must call Thyi.init to initial cookiePath";
      }
      cookieJar = PersistCookieJar(dir: _cookiePath);
    } else {
      cookieJar = CookieJar();
    }
    interceptors.add(CookieManager(cookieJar));
  }

}

/// 代表某条api
class ApiMethod {
  String method;
  String path = '';
  Map<String, String> headers = {};
  Map<String, String> fields = {};
  Map<String, String> queries = {};

  ApiMethod(this.method, this.path, {this.headers, this.fields, this.queries});

  Future<String> send(Thyi thyi) {
    var options = Options();
    var dio = thyi.dio;
    
    if (headers != null && headers.isNotEmpty) {
      options.headers.addAll(headers);
    }

    logi('url: ${dio.options.baseUrl}, path: ${path} fileds: ${fields}');
    /// How to handle all method?
    if (isGet()) {
      return dio.get<String>(path, queryParameters: queries, options: options)
        .then((response) => _parseResponse(response));
    }
    else if (isPost()) {
      return dio.post<String>(path, queryParameters: queries, options: options, data: fields)
        .then((response) => _parseResponse(response));
    }
    else if (isDelete()) {
      return dio.delete<String>(path, queryParameters: queries, options: options, data: fields)
          .then((response) => _parseResponse(response));
    }
    else {
      return Future.error('for now unsupport http method; ${method}');
    }

  }  

  String _parseResponse(Response response) {
    var rst = response.data.toString();
    logi("response: $rst");
    return rst;
  }


  bool isGet() {
    return "GET" == method.toUpperCase();
  }

  bool isPost() {
    return "POST" == method.toUpperCase();
  }

  bool isDelete() {
    return "DELETE" == method.toUpperCase();
  }
}
